﻿using Android.App;
using Android.OS;
using ThinkGeo.MapSuite.AndroidEdition;
using ThinkGeo.MapSuite.Core;

namespace ZoomToCurrentCoordinatesUsingBing
{
    [Activity(Label = "ZoomToCurrentCoordinatesUsingBing", MainLauncher = true, Icon = "@drawable/icon")]
    public class MainActivity : Activity
    {
        private MapView androidMap;

        static MainActivity()
        {
            PclShareEnvironment.Current = new AndroidEditionPclShareEnviroment();
        }

        protected override void OnCreate(Bundle bundle)
        {
            base.OnCreate(bundle);
            SetContentView(Resource.Layout.DisplayASimpleMap);

            PointShape thinkGeoCoordinate = new PointShape(153.5084, -28.5537);
            RectangleShape defaultExtent = new RectangleShape(151.209389, -33.430000, 151.219389, -34.29000);

            ManagedProj4Projection wgs84ToBingProjection = new ManagedProj4Projection();
            wgs84ToBingProjection.InternalProjectionParametersString = ManagedProj4Projection.GetWgs84ParametersString();
            wgs84ToBingProjection.ExternalProjectionParametersString = ManagedProj4Projection.GetBingMapParametersString();
            wgs84ToBingProjection.Open();
            defaultExtent = wgs84ToBingProjection.ConvertToExternalProjection(defaultExtent);
            thinkGeoCoordinate = (PointShape)wgs84ToBingProjection.ConvertToExternalProjection(thinkGeoCoordinate);
            wgs84ToBingProjection.Close();

            androidMap = FindViewById<MapView>(Resource.Id.androidmap);
            androidMap.MapUnit = GeographyUnit.Meter;
            androidMap.ZoomLevelSet = new BingMapsZoomLevelSet();
            androidMap.CurrentExtent = thinkGeoCoordinate.Buffer(500, GeographyUnit.Meter, DistanceUnit.Meter).GetBoundingBox();

            BingMapsTileOverlay bingMapOverlay = new BingMapsTileOverlay("Your application id");
            bingMapOverlay.MapType = BingMapsMapType.AerialWithLabels;
            androidMap.Overlays.Add(bingMapOverlay);

            Marker thinkGeoLocation = new Marker(this);
            thinkGeoLocation.Position = thinkGeoCoordinate;
            thinkGeoLocation.OffsetX = -22;
            thinkGeoLocation.SetImageResource(Resource.Drawable.Point);
            MarkerOverlay markerOverlay = new MarkerOverlay();
            markerOverlay.Markers.Add(thinkGeoLocation);
            androidMap.Overlays.Add("markerOverlay", markerOverlay);
        }
    }
}